@@ -11,7 +11,6 @@ from rich.console import Console
 from xefab.entrypoints import get_entry_points
 from xefab.utils import console
 
-
 dirs = appdirs.AppDirs("xefab")
 
 XEFAB_CONFIG = os.getenv(
@@ -95,9 +94,10 @@ class Config(FabricConfig):
 
         ours = {
             "tasks": {
-                "collection_name": "xefab",
+                "collection_name": "xetasks",
             },
             "xenon_config_paths": Config.get_xenon_config_paths(),
+            "list-depth": 3,
         }
 
         merge_dicts(defaults, ours)
