@@ -1,9 +1,9 @@
 from xefab.collection import XefabCollection
-from xefab.tasks import utils
-from .jupyter_task import start_jupyter
-from .squeue_task import squeue
-from .transfer_tasks import download_file, upload_file
-from .batchq import submit_job
+from xefab.tasks.batchq import sbatch
+from xefab.tasks.jupyter import start_jupyter
+from xefab.tasks.main import show_context
+from xefab.tasks.squeue import squeue
+from xefab.tasks.transfer import download_file, upload_file
 
 namespace = XefabCollection("dali")
 
@@ -15,5 +15,5 @@ namespace.add_task(squeue)
 namespace.add_task(start_jupyter)
 namespace.add_task(download_file)
 namespace.add_task(upload_file)
-namespace.add_task(submit_job)
-namespace.add_task(utils.show_context)
+namespace.add_task(sbatch)
+namespace.add_task(show_context)
